#!/bin/bash
#
# Bookstack Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_bookstack() {
  echo -ne "\n* Configuring /federated/apps/bookstack container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/bookstack" ]; then
    mkdir -p /federated/apps/bookstack/data/config
  fi

cat > /federated/apps/bookstack/docker-compose.yml <<EOF
version: "3.7"
services:
  bookstack:
    image: lscr.io/linuxserver/bookstack:\${IMAGE_VERSION}
    container_name: bookstack
    hostname: bookstack.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.36
    env_file:
      - ./.env
    volumes:
      - ./data/config:/config
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.bookstack.rule=Host(\`bookstack.$DOMAIN\`,\`documentation.$DOMAIN\`)"
      - "traefik.http.routers.bookstack.entrypoints=websecure"
      - "traefik.http.routers.bookstack.tls.certresolver=letsencrypt"

networks:
  federated:
    external: true
EOF

ADMINPASS=`cat /federated/apps/panel/.env | grep SMTP_PASSWORD | awk -F= '{ print $2 }'`
BOOKSTACK_ADMINPASSWORD=`htpasswd -bnBC 10 "" $ADMINPASS | tr -d ':\n' | sed 's/$2y/$2b/'`
BOOKSTACK_SECRET=$(create_password);
MYSQL_ROOTPASSWORD=`cat /federated/apps/pdnsmysql/.env | grep MYSQL_ROOT_PASSWORD | awk -F= '{ print $2 }'`

cat > /federated/apps/bookstack/.env <<EOF
IMAGE_VERSION="23.08.3"
PUID=1000
PGID=1000
APP_URL=https://bookstack.$DOMAIN
DB_HOST=pdnsmysql.$DOMAIN
DB_PORT=3306
DB_USER=bookstack
DB_PASS=$BOOKSTACK_SECRET
DB_PORT=3306
DB_DATABASE=bookstack
QUEUE_CONNECTION=database
#MAIL_DRIVER=smtp
MAIL_FROM=admin@$DOMAIN
MAIL_FROM_NAME=admin
MAIL_HOST=mail.$DOMAIN
MAIL_PORT=587
MAIL_USERNAME=admin
MAIL_PASSWORD=$ADMINPASS
MAIL_ENCRYPTION=TLS
EOF
chmod 600 /federated/apps/bookstack/.env

# Create database and user in mysql
docker exec pdnsmysql bash -c "mysql -uroot -p$MYSQL_ROOTPASSWORD -e 'create database bookstack;'"
docker exec pdnsmysql bash -c "mysql -uroot -p$MYSQL_ROOTPASSWORD -e \"CREATE USER 'bookstack'@'%' IDENTIFIED BY '$BOOKSTACK_SECRET';\""
docker exec pdnsmysql bash -c "mysql -uroot -p$MYSQL_ROOTPASSWORD -e \"grant all privileges on bookstack.* to 'bookstack'@'%';\""
docker exec pdnsmysql bash -c "mysql -uroot -p$MYSQL_ROOTPASSWORD -e 'flush privileges;'"
 
kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
start_bookstack() {
  # Start service with command to make sure it's up before proceeding
  start_service "bookstack" "nc -z 172.99.0.36 80 &> /dev/null" "7"

  docker exec pdns pdnsutil add-record $DOMAIN bookstack A 86400 $EXTERNALIP
  [ $? -ne 0 ] && fail "Couldn't add dns record for bookstack"

  PDNS_MYSQL_COMMAND="update users set password=\"$BOOKSTACK_ADMINPASSWORD\" where id = \"1\";"
  docker exec pdnsmysql bash -c "mysql -ubookstack -p$BOOKSTACK_SECRET bookstack -e '$PDNS_MYSQL_COMMAND;'"
  docker exec pdnsmysql bash -c "mysql -ubookstack -p$BOOKSTACK_SECRET bookstack -e \"update users set email='admin@$DOMAIN' where id = 1;\""

  # Set mail configuration
  sed -i "s#MAIL_FROM=.*#MAIL_FROM=admin@$DOMAIN#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_FROM_NAME=.*#MAIL_FROM_NAME=admin#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_HOST=.*#MAIL_HOST=mail.$DOMAIN#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_PORT=.*#MAIL_PORT=587#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_USERNAME=.*#MAIL_USERNAME=admin#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_PASSWORD=.*#MAIL_PASSWORD=$ADMINPASS#g" /federated/apps/bookstack/data/config/www/.env
  sed -i "s#MAIL_ENCRYPTION=.*#MAIL_ENCRYPTION=TLS#g" /federated/apps/bookstack/data/config/www/.env

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
